@@ -1092,9 +1092,23 @@ int bm_load_either(char *filename, int *nframes, int *fps, int *keyframe, int ca
 	return tidx;
 }
 
+/**
+ * Sanity check to ensure invalid bitmap handles are picked up early
+ *
+ * Some early known false or out of range handles (such as negative) are checked within
+ * an initial routine pass, followed by a more thorough check routine to ensure the
+ * series of bitmaps within the bm_bitmaps[] structure have not become invalid.
+ *
+ * @param handle Bitmap handle to check for validity
+ * @return 1 for valid, 0 for invalid
+ */
 int bm_is_valid(int handle)
 {
+	// Ensure that certain known false or out of range handles are quickly returned as invalid,
+	// prior to utilising the handle in a way which leads to memory access outside bm_bitmaps[]
 	if(!bm_inited) return 0;
+	if(handle < 0) return 0;
+    
 	return (bm_bitmaps[handle % MAX_BITMAPS].handle == handle);
 }
 
@@ -1833,7 +1847,7 @@ int bm_release(int handle, int clear_render_targets)
 		return 0;	// Already been released?
 	}
 
-	Assert( be->handle == handle );		// INVALID BITMAP HANDLE
+	Assertion( be->handle == handle, "Invalid bitmap handle number %d (expected %d) for %s passed to bm_release()\n", be->handle, handle, be->filename );
 
 	if ( !clear_render_targets && ((be->type == BM_TYPE_RENDER_TARGET_STATIC) || (be->type == BM_TYPE_RENDER_TARGET_DYNAMIC)) ) {
 		nprintf(("BmpMan", "Tried to release a render target!\n"));
