@@ -1447,12 +1447,9 @@ int cf_get_file_list( SCP_vector<SCP_string> &list, int pathtype, char *filter,
 	find_handle = _findfirst( filespec, &find );
 	if (find_handle != -1) {
 		do {
-            if (strcmp(strstr(filter, "."), strstr(find.name,".")) != 0)
+            if (strcmp(strrchr(filter, '.'), strrchr(find.name,'.')) != 0)
                 continue;
 
-			if ( strlen(find.name) >= MAX_FILENAME_LEN )
-				continue;
-
 			if (!(find.attrib & _A_SUBDIR)) {
 				if ( !Get_file_list_filter || (*Get_file_list_filter)(find.name) ) {
 					if ( check_duplicates && cf_file_already_in_list(list, find.name) ) {
@@ -1488,9 +1485,6 @@ int cf_get_file_list( SCP_vector<SCP_string> &list, int pathtype, char *filter,
 	dirp = opendir (filespec);
 	if ( dirp ) {
 		while ((dir = readdir (dirp)) != NULL) {
-			if ( strlen(dir->d_name) >= MAX_FILENAME_LEN ) {
-				continue;
-			}
 
 			if (fnmatch(filter, dir->d_name, 0) != 0)
 				continue;
@@ -1650,7 +1644,7 @@ int cf_get_file_list( int max, char **list, int pathtype, char *filter, int sort
 			if (num_files >= max)
 				break;
 
-            if (strcmp(strstr(filter, "."), strstr(find.name,".")) != 0)
+            if (strcmp(strrchr(filter, '.'), strrchr(find.name,'.')) != 0)
                 continue;
 
 			if ( strlen(find.name) >= MAX_FILENAME_LEN )
@@ -2040,14 +2034,6 @@ int cf_create_default_path_string( char *path, uint path_max, int pathtype, char
 			}
 		}
 
-#ifdef INF_BUILD
-		// keep pilot files separated for an Inferno build since they aren't compatible
-		if ( pathtype == CF_TYPE_SINGLE_PLAYERS || pathtype == CF_TYPE_MULTI_PLAYERS ) {
-			strcat_s(path, path_max, "inferno");
-			strcat_s(path, path_max, DIR_SEPARATOR_STR);
-		}
-#endif
-
 		// add filename
 		if (filename) {
 			strcat_s(path, path_max, filename);
