@@ -173,6 +173,16 @@ typedef struct flag_def_list {
 	ubyte var;
 } def_list;
 
+// weapon count list (mainly for pilot files)
+typedef struct wep_t {
+	int index;
+	int count;
+} wep_t;
+
+typedef struct coord2d {
+	int x,y;
+} coord2d;
+
 //This are defined in MainWin.c
 extern void _cdecl WinAssert(char * text,char *filename, int line);
 void _cdecl WinAssert(char * text, char * filename, int linenum, const char * format, ... );
