@@ -256,43 +256,6 @@ void gr_close()
 	Gr_inited = 0;
 }
 
-//XSTR:OFF
-DCF(gr,"Changes graphics mode")
-{
-	int mode = gr_screen.mode;
-
-	if ( Dc_command ) {
-		dc_get_arg(ARG_STRING);
-		
-		if ( !strcmp( Dc_arg, "o")) {
-			mode = GR_OPENGL;
-		} else {
-			// print usage, not stats
-			Dc_help = 1;
-		}
-	}
-
-	if ( Dc_help ) {
-		dc_printf( "Usage: gr mode\n" );
-		dc_printf( "The options can be:\n" );
-		dc_printf( "Macros:  A=software win32 window (obsolete)\n" );
-		dc_printf( "         B=software directdraw fullscreen (obsolete)\n" );
-		dc_printf( "         G=Glide (obsolete)\n" );
-		dc_printf( "         O=OpenGL\n" );
-		Dc_status = 0;	// don't print status if help is printed.  Too messy.
-	}
-
-	if ( Dc_status ) {
-		switch( gr_screen.mode ) {
-		case GR_OPENGL:
-			dc_printf( "OpenGl\n" );
-			break;
-		default:
-			Int3();		// Invalid graphics mode
-		}
-	}
-}
-//XSTR:ON
 
 /**
  * Set screen clear color
@@ -1464,6 +1427,28 @@ poly_list& poly_list::operator = (poly_list &other_list)
 	return *this;
 }
 
+void gr_shield_icon(coord2d coords[6], bool resize)
+{
+	if (gr_screen.mode == GR_STUB) {
+		return;
+	}
+
+	if (resize) {
+		gr_resize_screen_pos(&coords[0].x, &coords[0].y);
+		gr_resize_screen_pos(&coords[1].x, &coords[1].y);
+		gr_resize_screen_pos(&coords[2].x, &coords[2].y);
+		gr_resize_screen_pos(&coords[3].x, &coords[3].y);
+		gr_resize_screen_pos(&coords[4].x, &coords[4].y);
+		gr_resize_screen_pos(&coords[5].x, &coords[5].y);
+	}
+
+	g3_draw_2d_shield_icon(coords,
+		gr_screen.current_color.red,
+		gr_screen.current_color.green,
+		gr_screen.current_color.blue,
+		gr_screen.current_color.alpha);
+}
+
 void gr_rect(int x, int y, int w, int h, bool resize)
 {
 	if (gr_screen.mode == GR_STUB) {
