@@ -1602,7 +1602,9 @@ void hud_update_frame(float frametime)
 	}
 
 	hud_update_target_static();
-	hud_update_ship_status(targetp);
+	if ( (targetp->instance >=0) && (targetp->instance < MAX_SHIPS) ) {
+		hud_update_ship_status(targetp);
+	}
 }
 
 /**
@@ -2902,7 +2904,7 @@ void HudGaugeSupport::render(float frametime)
 		if ( Hud_support_objnum == -1 ) {
 			if (The_mission.support_ships.arrival_location == ARRIVE_FROM_DOCK_BAY)
 			{
-				strcpy_s(outstr, XSTR( "exiting hangar", -1));
+				strcpy_s(outstr, XSTR( "exiting hangar", 1622));
 			}
 			else
 			{
