@@ -299,12 +299,17 @@ void hud_lock_reset(float lock_time_scale)
 	ship_weapon	*swp;
 
 	swp = &Player_ship->weapons;
-	wip = &Weapon_info[swp->secondary_bank_weapons[swp->current_secondary_bank]];
+    
+	if (swp->current_secondary_bank > 0) {
+		wip = &Weapon_info[swp->secondary_bank_weapons[swp->current_secondary_bank]];
+		Player->lock_time_to_target = i2fl(wip->min_lock_time*lock_time_scale);
+	} else {
+		Player->lock_time_to_target = 0.0f;
+	}
 
 	Player_ai->current_target_is_locked = 0;
 	Players[Player_num].lock_indicator_visible = 0;
 	Player->target_in_lock_cone = 0;
-	Player->lock_time_to_target = i2fl(wip->min_lock_time*lock_time_scale);
 	Player->current_target_sx = -1;
 	Player->current_target_sy = -1;
 	Player->locking_subsys=NULL;
