@@ -14,6 +14,7 @@
 
 #include "menuui/barracks.h"
 #include "playerman/managepilot.h"
+#include "pilotfile/pilotfile.h"
 #include "ui/ui.h"
 #include "graphics/font.h"
 #include "io/key.h"
@@ -36,7 +37,7 @@
 
 
 //Returns 0 on failure, 1 on success
-int delete_pilot_file( char *pilot_name, int single );		// manage_pilot.cpp
+int delete_pilot_file( char *pilot_name );		// manage_pilot.cpp
 
 // stats defines
 //#define NUM_STAT_LINES (21 + MAX_SHIP_CLASSES)	// Goober5000
@@ -270,7 +271,7 @@ static int Num_stat_lines;
 static char (*Stat_labels)[STAT_COLUMN1_W];
 static char (*Stats)[STAT_COLUMN2_W];
 
-extern int Player_sel_mode;
+static int Player_sel_mode;
 
 static player *Cur_pilot;
 static int Num_pilots;
@@ -511,8 +512,7 @@ int barracks_new_pilot_selected()
 
 	// save the previous pilot first, so changes to it are kept
 	if (strlen(Cur_pilot->callsign)) {
-		write_pilot_file();
-		mission_campaign_savefile_save();
+		Pilot.save_player(Cur_pilot);
 	}
 
 	// check if we have a valid pilot hilighted.  If so, attempt to active it
@@ -521,43 +521,35 @@ int barracks_new_pilot_selected()
 		return -1;
 	}
 
-	// check to see if we are going to try and upgrade or not
-	if ( pilot_file_upgrade_check(Pilots[Selected_line], !Player_sel_mode) )
-		return -1;
-
-	if (read_pilot_file(Pilots[Selected_line], !Player_sel_mode, Cur_pilot)) {
+	if ( !Pilot.load_player(Pilots[Selected_line], Cur_pilot) ) {
 		Cur_pilot->callsign[0] = 0;  // this indicates no pilot active
 		return -1;
 	} else {
-		// we need to load up the current campaign file now so we can get at the stats - taylor
-		// had to change this to import the values to a specific player rather than global
-		if (Player_sel_mode == PLAYER_SELECT_MODE_SINGLE) {
-			mission_load_up_campaign(Cur_pilot);
-
-		/*	if (Campaign_file_missing) {
-				// error popup for a missing campaign file, abort loading of pilot in this case
-				// TODO: need to handle reading of info without the risk of saving improper data later
-				popup( PF_NO_NETWORKING, 1, POPUP_OK, XSTR( "The currently active campaign for this pilot cannot be found.  Unable to safely open pilot.", -1));
-				Cur_pilot->callsign[0] = 0; // this indicates no pilot active
-				return -1;
-			} */
+		if (!Pilot.load_savefile(Cur_pilot->current_campaign)) {
+			// set single player squad image to multi if campaign can't be loaded
+			strcpy_s(Cur_pilot->s_squad_filename, Cur_pilot->m_squad_filename);
 		}
 	}
 
 	// init stuff to reflect new pilot
 	int i;
 	barracks_init_stats(&Cur_pilot->stats);
+	strcpy_s(stripped, Cur_pilot->image_filename);
+	barracks_strip_pcx(stripped);
 	for (i=0; i<Num_pilot_images; i++) {
-		strcpy_s(stripped, Cur_pilot->image_filename);
-		barracks_strip_pcx(stripped);
 		if (!stricmp(stripped, Pilot_image_names[i])) {
 			break;
 		}
 	}
 	Pic_number = i;
+
+	if (Game_mode & GM_MULTIPLAYER) {
+		strcpy_s(stripped, Cur_pilot->m_squad_filename);
+	} else {
+		strcpy_s(stripped, Cur_pilot->s_squad_filename);
+	}
+	barracks_strip_pcx(stripped);
 	for ( i=0; i<Num_pilot_squad_images; i++) {
-		strcpy_s(stripped, Cur_pilot->squad_filename);
-		barracks_strip_pcx(stripped);
 		if (!stricmp(stripped, Pilot_squad_image_names[i])) {
 			break;
 		}
@@ -602,8 +594,7 @@ void barracks_create_new_pilot()
 	
 	// only write pilot file if there is an active pilot
 	if (strlen(Player->callsign)) {
-		write_pilot_file();
-		mission_campaign_savefile_save();
+		Pilot.save_player(Player);
 	}
 
 	// move other pilot names and ranks down to make room for the new one
@@ -633,28 +624,23 @@ void barracks_create_new_pilot()
 // exiting screen without canceling, so load in the new pilot selected here
 int barracks_pilot_accepted()
 {
-	char str[CALLSIGN_LEN + 1];
-
 	// check if pilot active.  If not, don't allow accept.
 	if (!Cur_pilot->callsign[0]){
 		return -1;
 	}
 
-	// set his image 
-	player_set_squad_bitmap(Cur_pilot, Cur_pilot->squad_filename);
-
-//	Skill_level = get_default_skill_level();
+	// set pilot image
+	if (Game_mode & GM_MULTIPLAYER) {
+		player_set_squad_bitmap(Cur_pilot, Cur_pilot->m_squad_filename, true);
+	} else {
+		player_set_squad_bitmap(Cur_pilot, Cur_pilot->s_squad_filename, false);
+	}
 
 	// MWA -- I think that we should be writing Cur_pilot here.
-	//write_pilot_file(!is_pilot_multi(Cur_pilot));
-	write_pilot_file( Cur_pilot );
-	
-	// when we store the LastPlayer key, we have to mark it as being single or multiplayer, so we know where to look for him
-	// (since we could have a single and a multiplayer pilot with the same callsign)
-	// we'll distinguish them by putting an M and the end of the multiplayer callsign and a P at the end of a single player
-	strcpy_s(str, Cur_pilot->callsign);
-	strcat_s(str, is_pilot_multi(Cur_pilot) ? NOX("M") : NOX("S"));
-	os_config_write_string( NULL, "LastPlayer", str );
+	Pilot.save_player(Cur_pilot);
+
+	os_config_write_string(NULL, "LastPlayer", Cur_pilot->callsign);
+
 	return 0;
 }
 
@@ -779,7 +765,11 @@ void barracks_prev_squad_pic()
 
 	// copy squad pic filename into pilot struct
 	if ((Pic_squad_number >= 0) && (Pic_squad_number < Num_pilot_squad_images)) {
-		strcpy_s(Cur_pilot->squad_filename, Pilot_squad_image_names[Pic_squad_number]);
+		if (Game_mode & GM_MULTIPLAYER) {
+			strcpy_s(Cur_pilot->m_squad_filename, Pilot_squad_image_names[Pic_squad_number]);
+		} else {
+			strcpy_s(Cur_pilot->s_squad_filename, Pilot_squad_image_names[Pic_squad_number]);
+		}
 	}
 
 	// play scroll sound
@@ -803,7 +793,11 @@ void barracks_next_squad_pic()
 
 	// copy squad pic filename into pilot struct
 	if ((Pic_squad_number >= 0) && (Pic_squad_number < Num_pilot_squad_images)){
-		strcpy_s(Cur_pilot->squad_filename, Pilot_squad_image_names[Pic_squad_number]);
+		if (Game_mode & GM_MULTIPLAYER) {
+			strcpy_s(Cur_pilot->m_squad_filename, Pilot_squad_image_names[Pic_squad_number]);
+		} else {
+			strcpy_s(Cur_pilot->s_squad_filename, Pilot_squad_image_names[Pic_squad_number]);
+		}
 	}
 
 	// play scroll sound
@@ -821,6 +815,14 @@ void barracks_delete_pilot()
 		return;
 	}
 
+	if (Player_sel_mode == PLAYER_SELECT_MODE_MULTI) {
+		gamesnd_play_iface(SND_GENERAL_FAIL);
+		popup(PF_TITLE_BIG | PF_TITLE_RED | PF_USE_AFFIRMATIVE_ICON, 1, POPUP_OK, XSTR("Disabled!\n\nMulti and single player pilots are now identical. "
+					"Deleting a multi-player pilot will also delete all single-player data for that pilot.\n\nAs a safety precaution, pilots can only be "
+					"deleted from the single-player menu.", 1598));
+		return;
+	}
+
 	int popup_rval = popup(PF_TITLE_BIG | PF_TITLE_RED, 2, POPUP_NO, POPUP_YES, XSTR( "Warning!\n\nAre you sure you wish to delete this pilot?", 65));
 	if (popup_rval != 1) {
 		return;
@@ -832,10 +834,10 @@ void barracks_delete_pilot()
 
 	strcpy_s(buf, Pilots[Selected_line]);
 
-	del_rval = delete_pilot_file(buf, (Player_sel_mode == PLAYER_SELECT_MODE_SINGLE) ? 1 : 0);
+	del_rval = delete_pilot_file(buf);
 
 	if ( !del_rval ) {
-		popup(PF_USE_AFFIRMATIVE_ICON | PF_TITLE_BIG | PF_TITLE_RED, 1, POPUP_OK, XSTR("Error\nFailed to delete pilot file. File may be read-only.", -1));
+		popup(PF_USE_AFFIRMATIVE_ICON | PF_TITLE_BIG | PF_TITLE_RED, 1, POPUP_OK, XSTR("Error\nFailed to delete pilot file. File may be read-only.", 1599));
 		return;
 	} else {
 		if (active) {
@@ -867,17 +869,19 @@ void barracks_delete_pilot()
 // Filter out pilots of wrong type (which shouldn't be in the directory we are checking, but just to be safe..)
 int barracks_pilot_filter(char *filename)
 {
-	int r, rank;
+	bool r = false;
+	int rank = 0;
+
+	r = Pilot.verify(filename, &rank);
 
-	r = verify_pilot_file(filename, Player_sel_mode == PLAYER_SELECT_MODE_SINGLE, &rank);
 	if (rank >= Rank_pips_count)
 		rank = Rank_pips_count - 1;
 
-	if (!r) {
+	if (r) {
 		Pilot_ranks[Num_pilots++] = rank;
 	}
 
-	return !r;
+	return (int)r;
 }
 
 // callback handler for the squadon selection buttons when they are disabled (in single player)
@@ -899,32 +903,13 @@ void barracks_init_player_stuff(int mode)
 	Num_pilots = 0;
 	Get_file_list_filter = barracks_pilot_filter;
 
+	Num_pilots = cf_get_file_list_preallocated(MAX_PILOTS, Pilots_arr, Pilots, CF_TYPE_PLAYERS, NOX("*.plr"), CF_SORT_TIME);
+
 	// single player specific stuff
 	if (mode == PLAYER_SELECT_MODE_SINGLE) {
-		int old_pilot_num = 0;
-		int new_pilot_num = 0;
-		char old_pilots_arr[MAX_PILOTS][MAX_FILENAME_LEN];
-		char *old_pilots[MAX_PILOTS];
-
 		Game_mode &= ~GM_MULTIPLAYER;
 		Game_mode |= GM_NORMAL;
 
-		Num_pilots = cf_get_file_list_preallocated(MAX_PILOTS, Pilots_arr, Pilots, CF_TYPE_SINGLE_PLAYERS, NOX("*.pl2"), CF_SORT_TIME);
-		old_pilot_num = cf_get_file_list_preallocated(MAX_PILOTS, old_pilots_arr, old_pilots, CF_TYPE_SINGLE_PLAYERS, NOX("*.plr"), CF_SORT_TIME);
-
-		new_pilot_num = MIN((Num_pilots + old_pilot_num), MAX_PILOTS);
-
-		for (i = Num_pilots; i<new_pilot_num;) {
-			for (j = 0; j<old_pilot_num; j++) {
-				if ( i >= MAX_PILOTS )
-					break;
-
-				strcpy( Pilots[i], old_pilots[j] );
-				Num_pilots++;
-				i++;
-			}
-		}
-
 		// disable squad logo switching		
 		Buttons[gr_screen.res][B_SQUAD_PREV_BUTTON].button.hide();
 		Buttons[gr_screen.res][B_SQUAD_PREV_BUTTON].button.disable();
@@ -934,12 +919,10 @@ void barracks_init_player_stuff(int mode)
 		Buttons[gr_screen.res][B_SQUAD_NEXT_BUTTON].button.set_disabled_action(barracks_squad_change_popup);
 	}
 	// multiplayer specific stuff
-	else {
+	else if (mode == PLAYER_SELECT_MODE_MULTI) {
 		Game_mode &= ~GM_NORMAL;
 		Game_mode |= GM_MULTIPLAYER;
 
-		Num_pilots = cf_get_file_list_preallocated(MAX_PILOTS, Pilots_arr, Pilots, CF_TYPE_MULTI_PLAYERS, NOX("*.plr"), CF_SORT_TIME);
-
 		// enable squad logo switching
 		Buttons[gr_screen.res][B_SQUAD_PREV_BUTTON].button.enable();
 		Buttons[gr_screen.res][B_SQUAD_PREV_BUTTON].button.unhide();
@@ -1008,20 +991,14 @@ void barracks_button_pressed(int n)
 				gamesnd_play_iface(SND_GENERAL_FAIL);
 
 				// if it's just the missing campaign file that failed for us then don't give the second popup
-				if (Campaign_file_missing)
+				if (Campaign_file_missing) {
 					break;
-
-				// throw up a popup telling the player that he should create a pilot first
-				if(Player_sel_mode == PLAYER_SELECT_MODE_SINGLE){
-					popup(PF_USE_AFFIRMATIVE_ICON,1,POPUP_OK,XSTR( "You must create a single player pilot.", 66));
-				} else {
-					popup(PF_USE_AFFIRMATIVE_ICON,1,POPUP_OK,XSTR( "You must create a multi player pilot.", 67));
 				}
 			} else {
 				gamesnd_play_iface(SND_SCROLL);
 
 				if (Campaign_file_missing) {
-					popup(PF_USE_AFFIRMATIVE_ICON, 1, POPUP_OK, XSTR( "The currently active campaign cannot be found.  Please select another...", -1));
+					popup(PF_USE_AFFIRMATIVE_ICON, 1, POPUP_OK, XSTR( "The currently active campaign cannot be found.  Please select another...", 1600));
 					gameseq_post_event(GS_EVENT_CAMPAIGN_ROOM);
 				}
 			}
@@ -1032,7 +1009,7 @@ void barracks_button_pressed(int n)
 				gamesnd_play_iface(SND_COMMIT_PRESSED);
 
 				if (Campaign_file_missing) {
-					popup(PF_USE_AFFIRMATIVE_ICON, 1, POPUP_OK, XSTR( "The currently active campaign cannot be found.  Please select another...", -1));
+					popup(PF_USE_AFFIRMATIVE_ICON, 1, POPUP_OK, XSTR( "The currently active campaign cannot be found.  Please select another...", 1600));
 					gameseq_post_event(GS_EVENT_CAMPAIGN_ROOM);
 				} else {
 					gameseq_post_event(GS_EVENT_MAIN_MENU);
@@ -1041,14 +1018,8 @@ void barracks_button_pressed(int n)
 				gamesnd_play_iface(SND_GENERAL_FAIL);
 
 				// if it's just the missing campaign file that failed for us then don't give the second popup
-				if (Campaign_file_missing)
+				if (Campaign_file_missing) {
 					break;
-
-				// throw up a popup telling the player that he should create a pilot first
-				if(Player_sel_mode == PLAYER_SELECT_MODE_SINGLE){
-					popup(PF_USE_AFFIRMATIVE_ICON,1,POPUP_OK,XSTR( "You must create a single player pilot.", 66));
-				} else {
-					popup(PF_USE_AFFIRMATIVE_ICON,1,POPUP_OK,XSTR( "You must create a multi player pilot.", 67));
 				}
 			}
 			break;
@@ -1064,52 +1035,22 @@ void barracks_button_pressed(int n)
 			break;
 
 		case B_PILOT_CONVERT_BUTTON: {
-			char temp[256], *str;
-			char old_pic[256] = "";
-			char old_squad_pic[256] = "";
-			char old_squad[256] = "";
-			int z;
-
-			if (!barracks_new_pilot_selected()) {
-				if (Player_sel_mode == PLAYER_SELECT_MODE_SINGLE)
-					str = XSTR( "multiplayer", 68);
-				else
-					str = XSTR( "single player", 69);
-
-				sprintf(temp, XSTR( "This will overwrite your %s pilot.  Proceed?", 70), str);
-				if (!verify_pilot_file(Cur_pilot->callsign, Player_sel_mode == PLAYER_SELECT_MODE_MULTI)) {
-					z = popup(0, 2, POPUP_CANCEL, POPUP_OK, temp);
-					if (z != 1)
-						break;
-				}
-
-				strcpy_s(old_pic, Cur_pilot->image_filename);
-				strcpy_s(old_squad_pic, Cur_pilot->squad_filename);
-				strcpy_s(old_squad, Cur_pilot->squad_name);
-				init_new_pilot(Cur_pilot, 0);
-				strcpy_s(Cur_pilot->image_filename, old_pic);
-				strcpy_s(Cur_pilot->squad_filename, old_squad_pic);
-				strcpy_s(Cur_pilot->squad_name, old_squad);
-				if (Player_sel_mode == PLAYER_SELECT_MODE_SINGLE) {
-					Cur_pilot->flags |= PLAYER_FLAGS_IS_MULTI;
-					write_pilot_file();
-					barracks_init_player_stuff(PLAYER_SELECT_MODE_MULTI);
-
-				} else {
-					// make sure we don't carry over the multi flag
-					if (Cur_pilot->flags & PLAYER_FLAGS_IS_MULTI)
-						Cur_pilot->flags &= ~PLAYER_FLAGS_IS_MULTI;
-
-					write_pilot_file();
-					mission_campaign_savefile_save();
-					barracks_init_player_stuff(PLAYER_SELECT_MODE_SINGLE);
-				}
-
-				gamesnd_play_iface(SND_USER_SELECT);
-
+	/*	New Pilot code no longer needs a conversion function. */
+			popup(PF_TITLE_BIG | PF_TITLE_BLUE | PF_USE_AFFIRMATIVE_ICON, 1, POPUP_OK,
+				XSTR("Disabled!\n\n\nMulti and Single Player Pilot files are now identical.\n\n"
+				"Conversion between the two is no longer necessary.", 1601));
+		/*	// no actual conversion with new pilot code
+			if (Player_sel_mode == PLAYER_SELECT_MODE_SINGLE) {
+				barracks_init_player_stuff(PLAYER_SELECT_MODE_MULTI);
 			} else {
-				gamesnd_play_iface(SND_GENERAL_FAIL);
+				// make sure we don't carry over the multi flag
+				if (Cur_pilot->flags & PLAYER_FLAGS_IS_MULTI) {
+					Cur_pilot->flags &= ~PLAYER_FLAGS_IS_MULTI;
+				}
+				barracks_init_player_stuff(PLAYER_SELECT_MODE_SINGLE);
 			}
+
+			gamesnd_play_iface(SND_USER_SELECT);	*/
 			break;
 		}
 
@@ -1140,8 +1081,13 @@ void barracks_button_pressed(int n)
 		case B_PILOT_SINGLE_MODE_BUTTON:
 			if (Player_sel_mode != PLAYER_SELECT_MODE_SINGLE) {
 				gamesnd_play_iface(SND_USER_SELECT);
+				// make sure we don't carry over the multi flag
+				if (Cur_pilot->flags & PLAYER_FLAGS_IS_MULTI) {
+					Cur_pilot->flags &= ~PLAYER_FLAGS_IS_MULTI;
+				}
+				Pilot.save_player(Cur_pilot);
 				barracks_init_player_stuff(PLAYER_SELECT_MODE_SINGLE);
-			}						
+			}
 			break;
 
 		case B_PILOT_MULTI_MODE_BUTTON:
@@ -1152,6 +1098,8 @@ void barracks_button_pressed(int n)
 
 			if (Player_sel_mode != PLAYER_SELECT_MODE_MULTI) {
 				gamesnd_play_iface(SND_USER_SELECT);
+				Cur_pilot->flags |= PLAYER_FLAGS_IS_MULTI;
+				Pilot.save_player(Cur_pilot);
 				barracks_init_player_stuff(PLAYER_SELECT_MODE_MULTI);
 			}
 			break;
@@ -1174,7 +1122,7 @@ void barracks_display_pilot_callsigns(int prospective_pilot)
 		if (cur_pilot_idx >= Num_pilots)
 			break;
 
-		if (!stricmp(Cur_pilot->callsign, Pilots[cur_pilot_idx]) && (is_pilot_multi(Cur_pilot) == multi)) {
+		if (!stricmp(Cur_pilot->callsign, Pilots[cur_pilot_idx]) && multi) {
 			gr_set_color_fast(&Color_text_active);
 		} else {
 			if (cur_pilot_idx == Selected_line) {
@@ -1269,7 +1217,7 @@ void barracks_accept_new_pilot_callsign()
 				}
 
 				Num_pilots--;
-				delete_pilot_file(name, Player_sel_mode == PLAYER_SELECT_MODE_SINGLE ? 1 : 0);
+				delete_pilot_file(name);
 				z = 0;
 			}
 			return;
@@ -1299,7 +1247,7 @@ void barracks_accept_new_pilot_callsign()
 	}
 
 	if ( !(Game_mode & GM_STANDALONE_SERVER) ) {
-		write_pilot_file(Cur_pilot);
+		Pilot.save_player(Cur_pilot);
 	}
 
 	Selected_line = 0;
@@ -1367,8 +1315,7 @@ void barracks_init()
 	UI_WINDOW *w = &Ui_window;
 
 	// save current pilot file, so we don't possibly loose it.
-	write_pilot_file();
-	mission_campaign_savefile_save();
+	Pilot.save_player();
 
 	// create interface
 	Ui_window.create(0, 0, gr_screen.max_w_unscaled, gr_screen.max_h_unscaled, 0);
@@ -1408,7 +1355,7 @@ void barracks_init()
 	w->add_XSTR("Clone",  1040, Buttons[gr_screen.res][13].text_x,  Buttons[gr_screen.res][13].text_y, &Buttons[gr_screen.res][13].button, UI_XSTR_COLOR_GREEN);
 	w->add_XSTR("Single", 1041, Buttons[gr_screen.res][14].text_x,  Buttons[gr_screen.res][14].text_y,  &Buttons[gr_screen.res][14].button, UI_XSTR_COLOR_GREEN);
 	w->add_XSTR("Multi",  1042, Buttons[gr_screen.res][15].text_x,  Buttons[gr_screen.res][15].text_y,  &Buttons[gr_screen.res][15].button, UI_XSTR_COLOR_GREEN);
-	w->add_XSTR("Convert",1043, Buttons[gr_screen.res][16].text_x,  Buttons[gr_screen.res][16].text_y, &Buttons[gr_screen.res][16].button, UI_XSTR_COLOR_GREEN);	
+//	w->add_XSTR("Convert",1043, Buttons[gr_screen.res][16].text_x,  Buttons[gr_screen.res][16].text_y, &Buttons[gr_screen.res][16].button, UI_XSTR_COLOR_GREEN);	
 	for(i=0; i<BARRACKS_NUM_TEXT; i++) {
 		w->add_XSTR(&Barracks_text[gr_screen.res][i]);
 	}
@@ -1467,7 +1414,7 @@ void barracks_init()
 	barracks_init_stats(&Cur_pilot->stats);
 	
 	// base the mode we're in (single or multi) on the status of the currently selected pilot
-	barracks_init_player_stuff(is_pilot_multi(Player));
+	barracks_init_player_stuff((Game_mode & GM_MULTIPLAYER) == GM_MULTIPLAYER);
 }
 
 // -----------------------------------------------------------------------------
